@@ -12,7 +12,6 @@ import astropy.io.fits
 from astropy.utils import iers
 
 from sunpy.data.test import get_test_data_filenames, get_test_filepath, write_image_file_from_header_file
-from sunpy.map import Map
 from sunpy.util import SunpyUserWarning
 
 # Force MPL to use non-gui backends for testing.
@@ -128,11 +127,11 @@ def sunpy_test_run(request):
 @pytest.fixture(scope='session', autouse=True)
 def hide_parfive_progress(request):
     """
-    Set the PARFIVE_HIDE_PROGESS to hide the parfive progress bar in tests.
+    Set the PARFIVE_HIDE_PROGRESS to hide the parfive progress bar in tests.
     """
-    os.environ["PARFIVE_HIDE_PROGESS"] = "True"
+    os.environ["PARFIVE_HIDE_PROGRESS"] = "True"
     yield
-    del os.environ["PARFIVE_HIDE_PROGESS"]
+    del os.environ["PARFIVE_HIDE_PROGRESS"]
 
 
 @pytest.fixture(scope='session', autouse=True)
@@ -191,6 +190,7 @@ def pytest_runtest_teardown(item):
 
 @pytest.fixture(scope="session")
 def aia171_test_map():
+    from sunpy.map import Map
     return Map(get_test_filepath('aia_171_level1.fits'))
 
 
@@ -206,16 +206,3 @@ def eit_fits_directory(tmp_path_factory):
     for f in eit_header_files:
         _ = write_image_file_from_header_file(f, eit_dir)
     return pathlib.Path(eit_dir)
-
-
-@pytest.fixture(scope="session")
-def waveunit_fits_directory(tmp_path_factory):
-    # Create a temporary directory of dummy FITS files
-    # from the header data. This directory is then used to
-    # test directory patterns for database
-    waveunit_dir = tmp_path_factory.mktemp('waveunit')
-    header_files = [f for f in get_test_data_filenames()
-                    if f.parents[0].relative_to(f.parents[1]).name == 'waveunit']
-    for f in header_files:
-        _ = write_image_file_from_header_file(f, waveunit_dir)
-    return pathlib.Path(waveunit_dir)
