@@ -6,7 +6,7 @@ Based on Michiel van Noort's IDL DLM library 'f0' which contains
 a cleaned up version of the original anarw routines.
 */
 
-#define Py_LIMITED_API 0x030900f0
+#define Py_LIMITED_API 0x030A0000
 
 // Needed due to https://github.com/numpy/numpy/issues/16970
 struct _typeobject {
