@@ -83,15 +83,22 @@ def test_patterns(eit_fits_directory):
     maps = sunpy.map.Map(os.fspath(eit_fits_directory))
     assert isinstance(maps, list)
     assert ([isinstance(amap, sunpy.map.GenericMap) for amap in maps])
+
     # Test that returned maps are sorted
     files_sorted = sorted(list(eit_fits_directory.glob('*')))
     maps_sorted = [sunpy.map.Map(os.fspath(f)) for f in files_sorted]
-    assert all([m.date == m_s.date for m, m_s in zip(maps, maps_sorted)])
+    assert all(m.date == m_s.date for m, m_s in zip(maps, maps_sorted))
 
     # Pathlib
     path = pathlib.Path(AIA_171_IMAGE)
     aiamap = sunpy.map.Map(path)
+
+    # Generator
+    maps = sunpy.map.Map(eit_fits_directory.glob('*.fits'))
+    assert isinstance(maps, list)
     assert isinstance(aiamap, sunpy.map.GenericMap)
+
+    # A directory
     maps = sunpy.map.Map(eit_fits_directory)
     assert isinstance(maps, list)
     assert ([isinstance(amap, sunpy.map.GenericMap) for amap in maps])
@@ -101,16 +108,19 @@ def test_patterns(eit_fits_directory):
     maps = sunpy.map.Map(pattern)
     assert isinstance(maps, list)
     assert ([isinstance(amap, sunpy.map.GenericMap) for amap in maps])
+
     # Test that returned maps are sorted
     files_sorted = sorted(list(pathlib.Path(pattern).parent.glob('*')))
     maps_sorted = [sunpy.map.Map(os.fspath(f)) for f in files_sorted]
-    assert all([m.date == m_s.date for m, m_s in zip(maps, maps_sorted)])
+    assert all(m.date == m_s.date for m, m_s in zip(maps, maps_sorted))
+
     # Single character wildcard (?)
     pattern = os.path.join(eit_fits_directory, "efz20040301.0?0010_s.fits")
     maps = sunpy.map.Map(pattern)
     assert isinstance(maps, list)
     assert len(maps) == 7
     assert ([isinstance(amap, sunpy.map.GenericMap) for amap in maps])
+
     # Character ranges
     pattern = os.path.join(eit_fits_directory, "efz20040301.0[2-6]0010_s.fits")
     maps = sunpy.map.Map(pattern)
@@ -227,16 +237,6 @@ def test_dask_array():
     assert isinstance(pair_map, sunpy.map.GenericMap)
 
 
-def test_databaseentry():
-    pytest.importorskip('sqlalchemy')
-    sunpy_database = pytest.importorskip('sunpy.database')
-    db = sunpy_database.Database(url='sqlite://', default_waveunit='angstrom')
-    db.add_from_file(AIA_171_IMAGE)
-    res = db.get_entry_by_id(1)
-    db_map = sunpy.map.Map(res)
-    assert isinstance(db_map, sunpy.map.GenericMap)
-
-
 @pytest.mark.remote_data
 def test_url_pattern():
     # A URL
@@ -284,6 +284,7 @@ def test_sources(file, mapcls):
     m = get_dummy_map_from_header(p) if p.suffix == '.header' else sunpy.map.Map(p)
     assert isinstance(m, mapcls)
 
+
 @pytest.mark.skipif(pytest.__version__ < "8.0.0", reason="pytest >= 8.0.0 raises a warning for this test")
 def test_no_2d_hdus(tmpdir):
     # Create a fake FITS file with a valid header but 1D data
