@@ -208,13 +208,12 @@ def testFilesRange_sameDirectory_months_remote():
 
 @pytest.mark.remote_data
 def test_ftp():
-    pattern = 'ftp://solar-pub.nao.ac.jp/pub/nsro/norh/data/tcx/%Y/%m/tca%y%m%d'
+    pattern = 'ftp://ftp.ngdc.noaa.gov/STP/swpc_products/daily_reports/solar_region_summaries/%Y/%m/%Y%m%dSRS.txt'
     s = Scraper(pattern)
-    timerange = TimeRange('2016/5/18 15:28:00', '2016/5/20 16:30:50')
+    timerange = TimeRange('2024/5/18', '2024/5/20')
     urls = s.filelist(timerange)
-    assert urls[0] == ('ftp://solar-pub.nao.ac.jp'
-                       '/pub/nsro/norh/data/tcx/2016/05/tca160518')
-    assert len(urls) == 3
+    assert urls[0] == ('ftp://ftp.ngdc.noaa.gov/STP/swpc_products/daily_reports/solar_region_summaries/2024/05/20240517SRS.txt')
+    assert len(urls) == 4
 
 
 @pytest.mark.remote_data
@@ -261,7 +260,7 @@ def test_regex_data():
 
 @pytest.mark.remote_data
 def test_extract_files_meta():
-    baseurl0 = r'ftp://solar-pub.nao.ac.jp/pub/nsro/norh/data/tcx/%Y/%m/(\w){3}%y%m%d'
+    baseurl0 = r'https://solar.nro.nao.ac.jp/norh/data/tcx/%Y/%m/(\w){3}%y%m%d'
     extractpattern0 = '{}/tcx/{year:4d}/{month:2d}/{wave}{:4d}{day:2d}'
     s0 = Scraper(baseurl0, regex=True)
     timerange0 = TimeRange('2020/1/1 4:00', '2020/1/2')
