@@ -13,3 +13,8 @@ from sunpy.timeseries.sources.lyra import LYRATimeSeries
 from sunpy.timeseries.sources.noaa import NOAAIndicesTimeSeries, NOAAPredictIndicesTimeSeries
 from sunpy.timeseries.sources.norh import NoRHTimeSeries
 from sunpy.timeseries.sources.rhessi import RHESSISummaryTimeSeries
+
+__all__ = ['ESPTimeSeries', 'EVESpWxTimeSeries', 'GBMSummaryTimeSeries', 'XRSTimeSeries', 'LYRATimeSeries',
+           'NOAAIndicesTimeSeries', 'NOAAPredictIndicesTimeSeries', 'NoRHTimeSeries', 'RHESSISummaryTimeSeries']
+
+source_names = {globals()[s]._source for s in __all__}
